@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Ethon::Easy do
@@ -105,8 +106,9 @@ describe Ethon::Easy do
       easy.url = "http://localhost:3001/"
       easy.on_complete { 'on_complete' }
       easy.on_headers { 'on_headers' }
-      easy.response_body = 'test_body'
-      easy.response_headers = 'test_headers'
+      easy.on_progress { 'on_progress' }
+      easy.response_body = String.new('test_body')
+      easy.response_headers = String.new('test_headers')
       easy
     end
     let!(:e) { easy.dup }
@@ -132,6 +134,10 @@ describe Ethon::Easy do
       expect { easy.perform }.not_to change { e.response_body }
     end
 
+    it "preserves on_progress callback" do
+      expect(e.on_progress).to be(easy.on_progress)
+    end
+
     it 'sets new body_write_callback of duplicated handle' do
       expect { e.perform }.to change { e.response_body }
       expect { e.perform }.not_to change { easy.response_body }
